﻿using UnityEngine;
using System.Collections;
using UnityEngine.UI;

public class WeaponShopButton : MonoBehaviour {

    public PlayerStats stats; // to set the weapon
    public int weaponNumber;
    public Text wepName;
    public Text description;
    public Text cost;
    public Image imageDisplay;
	private WeaponStats[] weapons; // to get access to weapon array
    public Money money; // to access and manipulate coin amount
    private int price;
    public Button shopButton; // to access button colours
    private ColorBlock block;

    public bool purchased; // to check if the weapon is purchased or not for display reasons
    // ** brute force purchased persistence over scenes. Will continue to try to make this dynamic during the polish stage
    private static bool purchasedBasicAxe = false;
    private static bool purchasedMedAxe = false; 
    private static bool purchasedHeavyAxe = false;
    private static bool purchasedShortSword = false;
    private static bool purchasedLongSword = false;
    private static bool purchasedKatana = false;

    /*
     * BUTTON NAVIGATION IS SET TO NONE - WILL HAVE TO TWEAK IF WE DECIDE ON CONTROLLER IMPLEMENTATION
     * this fixes the button staying on the highlighted colour when clicked, will most likely do the same
     * for the character creation screen.
     */
    void Start () {
        //money = GameObject.Find("Coins").GetComponent<Money>();
        //shopButton = GameObject.Find("Button").GetComponent<Button>();
        stats = GameObject.Find("Player").GetComponent<PlayerStats>();
        weapons = GameObject.Find("Canvas").GetComponent<WeaponList>().weapons;
        price = weapons[weaponNumber].cost;
        setButton();
        block = new ColorBlock();
        block = shopButton.colors;

        // *** BRUTE FORCE purchased code - hopefully to be changed
        if (weapons[weaponNumber].weaponName == "Basic Axe" && purchasedBasicAxe == true) {
            purchased = true;
        }
        else if (weapons[weaponNumber].weaponName == "Medium Axe" && purchasedMedAxe == true) {
            purchased = true;
        }
        else if (weapons[weaponNumber].weaponName == "Heavy Axe" && purchasedHeavyAxe == true) {
            purchased = true;
        }
        if (weapons[weaponNumber].weaponName == "Short Sword" && purchasedBasicAxe == true) {
            purchased = true;
        }
        else if (weapons[weaponNumber].weaponName == "Long Sword" && purchasedMedAxe == true) {
            purchased = true;
        }
        else if (weapons[weaponNumber].weaponName == "Katana" && purchasedHeavyAxe == true) {
            purchased = true;
        }
    }

	
    // neccesary for colour changes to be in update.
	void Update () {
        // changing on press colors
        if (money.getMoney() >= price || cost.text == "PURCHASED" || cost.text == "EQUIPPED") {
            block.pressedColor = Color.gray;
            shopButton.colors = block;
            if (cost.text == "EQUIPPED") {
                cost.color = Color.green;
            }
            else {
                cost.color = Color.black;
            }
        }
        else {
            block.pressedColor = Color.red; // can't afford = red click
            shopButton.colors = block;
        }

        // changing between the cost, "purchased", and "equipped"
        if (stats.getWeapon().weaponName == weapons[weaponNumber].weaponName) {
            cost.text = "EQUIPPED";
        }
        else if (purchased == true) {
            cost.text = "PURCHASED";
        }
        else {
            cost.text = weapons[weaponNumber].cost.ToString();
        }

    }

    // created by following the 'Creating An In-Game Shop' shop tutorial on unity3d.com
    // dynamically allocates the shop buttons based on created weapons
    void setButton() {
        string costToString = weapons[weaponNumber].cost.ToString(); // convert float to string
        wepName.text = weapons[weaponNumber].weaponName;
        description.text = weapons[weaponNumber].weaponDescription;
        //cost.text = costToString;
        imageDisplay.sprite = weapons[weaponNumber].image;
    }

    public void OnClick() { 
        // buying the weapons based on currency
        if (money.getMoney() >= price && cost.text != "PURCHASED" && cost.text != "EQUIPPED") {
            money.decreaseCoins(price);
            stats.setWeapon(weapons[weaponNumber]);
            cost.color = Color.green;
            purchased = true;

            // *** BRUTE FORCE purchased code - hopefully to be changed
            if (stats.getWeapon().weaponName == "Basic Axe") {
                purchasedBasicAxe = true;
            }
            else if (stats.getWeapon().weaponName == "Medium Axe") {
                purchasedMedAxe = true;
            }
            else if (stats.getWeapon().weaponName == "Heavy Axe") {
                purchasedHeavyAxe = true;
            }
            else if (stats.getWeapon().weaponName == "Short Sword") {
                purchasedBasicAxe = true;
            }
            else if (stats.getWeapon().weaponName == "Long Sword") {
                purchasedMedAxe = true;
            }
            else if (stats.getWeapon().weaponName == "Katana") {
                purchasedHeavyAxe = true;
            }
        }
        else if (cost.text == "PURCHASED") { // already purchased, just equip.
            stats.setWeapon(weapons[weaponNumber]);
            cost.text = "EQUIPPED";
        }
        else {
            // will implement sound that the player cannot afford here. (visual handled in update)
        }
       

    }

    // to display weapon stats when you hover over a weapon
    public void HoverEnter() {
        description.text = "Damage:\n" + weapons[weaponNumber].damageMin.ToString() + " - " 
            + weapons[weaponNumber].damageMax.ToString() + "\n\n" + "Attack Speed:\n" 
            + weapons[weaponNumber].attackSpeed.ToString();
    }

    // to revert back to the original description
    public void HoverExit() {
        description.text = weapons[weaponNumber].weaponDescription;
    }
}
